@@ -33,7 +33,6 @@ fortify.ts <- function(model, data = NULL, columns = NULL, is.date = NULL,
   } else if (is(model, 'stl')) {
       # stl allows only univariate series
       ts.data <- model$time.series
-      ncomp <- ncol(ts.data)
       orig <- drop(ts.data %*% rep(1, ncol(ts.data)))
 
       dtindex <- get.dtindex(ts.data, is.date = is.date)
@@ -44,7 +43,6 @@ fortify.ts <- function(model, data = NULL, columns = NULL, is.date = NULL,
       dtframe <- ggplot2::fortify(model$x)
 
       # for tbl_df
-      # dtframe <- dtframe[, -1]
       dtframe <- data.frame(Data = dtframe[['Data']])
 
       # trend and random can be multivariate
@@ -167,17 +165,19 @@ autoplot.ts <- function(object, columns = NULL, group = NULL,
       columns <- data.names[data.names != index.name]
     }
   }
+
   if (length(columns) > 1) {
     .is.univariate <- FALSE
   } else {
     .is.univariate <- TRUE
   }
+
   plot.data <- tidyr::gather_(plot.data, 'variable', 'value', columns)
 
   # create ggplot instance if not passed
   if (is.null(p)) {
     null.p <- TRUE
-    mapping = ggplot2::aes_string(x = index.name)
+    mapping <- ggplot2::aes_string(x = index.name)
     p <- ggplot2::ggplot(data = plot.data, mapping = mapping)
   } else {
     null.p <- FALSE
@@ -330,7 +330,6 @@ fortify.tsmodel <- function(model, data = NULL,
   d <- dplyr::left_join(d, fit, by = 'Index')
   d <- dplyr::left_join(d, resid, by = 'Index')
   if (!is.null(predict)) {
-    n <- nrow(d)
     d <- rbind_ts(pred, d, ts.connect = ts.connect)
   }
   post_fortify(d)
