@@ -14,6 +14,9 @@ test_that('fortify.kmeans works for iris', {
   expect_equal(colnames(fortified), c(colnames(iris), 'cluster'))
   expect_equal(is.factor(fortified$cluster), TRUE)
   expect_equal(rownames(fortified), rownames(df))
+
+  expect_that(ggplot2::autoplot(stats::kmeans(df, 3), data = df), not(throws_error()))
+  expect_that(ggplot2::autoplot(stats::kmeans(df, 3)), throws_error())
 })
 
 test_that('fortify.partition works for iris', {
@@ -31,6 +34,9 @@ test_that('fortify.partition works for iris', {
   expect_equal(is.factor(fortified$cluster), TRUE)
   expect_equal(rownames(fortified), rownames(df))
 
+  p <- autoplot(cluster::clara(df, 3), data = iris)
+  expect_true(inherits(p, 'ggplot'))
+
   # fanny
   fortified <- ggplot2::fortify(cluster::fanny(df, 3))
   expect_equal(is.data.frame(fortified), TRUE)
@@ -44,6 +50,9 @@ test_that('fortify.partition works for iris', {
   expect_equal(is.factor(fortified$cluster), TRUE)
   expect_equal(rownames(fortified), rownames(df))
 
+  p <- autoplot(cluster::fanny(df, 3), data = iris)
+  expect_true(inherits(p, 'ggplot'))
+
   # pam
   fortified <- ggplot2::fortify(cluster::pam(df, 3))
   expect_equal(is.data.frame(fortified), TRUE)
@@ -56,6 +65,9 @@ test_that('fortify.partition works for iris', {
   expect_equal(colnames(fortified), c(colnames(iris), 'cluster'))
   expect_equal(is.factor(fortified$cluster), TRUE)
   expect_equal(rownames(fortified), rownames(df))
+
+  p <- autoplot(cluster::pam(df, 3), data = iris)
+  expect_true(inherits(p, 'ggplot'))
 })
 
 test_that('fortify.partition works for USArrests', {
