@@ -3,7 +3,7 @@ library(survival)
 context('test survival')
 
 test_that('fortify.survfit works for lung', {
-  d.survfit <- survfit(Surv(time, status) ~ sex, data = lung)
+  d.survfit <- survival::survfit(Surv(time, status) ~ sex, data = lung)
   fortified <- ggplot2::fortify(d.survfit)
   expect_equal(is.data.frame(fortified), TRUE)
   expected_names <- c('time', 'n.risk', 'n.event', 'n.censor', 'surv',
@@ -11,6 +11,12 @@ test_that('fortify.survfit works for lung', {
   expect_equal(names(fortified), expected_names)
   expect_equal(dim(fortified), c(206, 9))
 
+  p <- ggplot2::autoplot(d.survfit)
+  expect_true(is(p, 'ggplot'))
+
+  p <- ggplot2::autoplot(d.survfit, surv.geom = 'line')
+  expect_true(is(p, 'ggplot'))
+
   fortified2 <- ggplot2::fortify(d.survfit, fun = 'event')
   expect_equal(is.data.frame(fortified), TRUE)
   expected_names <- c('time', 'n.risk', 'n.event', 'n.censor', 'surv',
@@ -21,6 +27,9 @@ test_that('fortify.survfit works for lung', {
   expect_equal(fortified$upper, 1 - fortified2$upper)
   expect_equal(fortified$lower, 1 - fortified2$lower)
 
+  p <- ggplot2::autoplot(d.survfit, fun = 'event')
+  expect_true(is(p, 'ggplot'))
+
   fortified <- ggplot2::fortify(d.survfit, surv.connect = TRUE)
   expect_equal(is.data.frame(fortified), TRUE)
   expected_names <- c('time', 'n.risk', 'n.event', 'n.censor', 'surv',
@@ -32,6 +41,12 @@ test_that('fortify.survfit works for lung', {
                          strata = as.factor(c('sex=1', 'sex=2')))
   expect_equal(fortified[1:2, ], expected)
 
+  p <- ggplot2::autoplot(d.survfit, surv.connect = TRUE)
+  expect_true(is(p, 'ggplot'))
+
+  p <- ggplot2::autoplot(d.survfit, surv.connect = FALSE)
+  expect_true(is(p, 'ggplot'))
+
   d.survfit <- survfit(Surv(time, status) ~ 1, data = lung)
   fortified <- ggplot2::fortify(d.survfit)
 
@@ -41,6 +56,9 @@ test_that('fortify.survfit works for lung', {
   expect_equal(names(fortified), expected_names)
   expect_equal(dim(fortified), c(186, 8))
 
+  p <- ggplot2::autoplot(d.survfit)
+  expect_true(is(p, 'ggplot'))
+
   fortified <- ggplot2::fortify(d.survfit, surv.connect = TRUE)
   expect_equal(is.data.frame(fortified), TRUE)
   expected_names <- c('time', 'n.risk', 'n.event', 'n.censor', 'surv',
@@ -50,6 +68,9 @@ test_that('fortify.survfit works for lung', {
   expected <- data.frame(time = 0, n.risk = 228, n.event = 1, n.censor = 0,
                          surv = 1, std.err = 0, upper = 1, lower = 1)
   expect_equal(fortified[1, ], expected)
+
+  p <- ggplot2::autoplot(d.survfit)
+  expect_true(is(p, 'ggplot'))
 })
 
 test_that('fortify.survfit works for simple data', {
@@ -58,7 +79,7 @@ test_that('fortify.survfit works for simple data', {
                       n = c(12, 3, 2, 6, 2, 4, 2, 0, 2, 3, 3, 5))
   fit  <- survfit(Surv(time, time, status, type='interval') ~1, data = tdata, weight = n)
   fortified <- fortify(fit)
-  expected = data.frame(time = c(1, 2, 3, 4),
+  expected <- data.frame(time = c(1, 2, 3, 4),
                         n.risk = c(44.000000000, 20.652979445, 9.318098786, 6.634779353),
                         n.event = c(20.347020555, 9.334880659, 2.683319433, 3.634779353),
                         n.censor = c(3, 2, 0, 3),
@@ -69,7 +90,7 @@ test_that('fortify.survfit works for simple data', {
   expect_equal(fortified, expected)
 
   fortified <- fortify(fit, surv.connect = TRUE)
-  expected = data.frame(time = c(0, 1, 2, 3, 4),
+  expected <- data.frame(time = c(0, 1, 2, 3, 4),
                         n.risk = c(44.000000000, 44.000000000, 20.652979445, 9.318098786, 6.634779353),
                         n.event = c(20.347020555, 20.347020555, 9.334880659, 2.683319433, 3.634779353),
                         n.censor = c(0, 3, 2, 0, 3),
@@ -79,13 +100,16 @@ test_that('fortify.survfit works for simple data', {
                         lower = c(1.0, 0.40870968683, 0.18264959088, 0.11186383878, 0.03328139035))
   expect_equal(fortified, expected)
 
+  p <- ggplot2::autoplot(fit)
+  expect_true(is(p, 'ggplot'))
+
   tdata <- data.frame(time = c(1, 1, 2, 2, 3, 3, 4, 4),
                       status = rep(c(1, 2), 4),
                       n = c(24, 3, 20, 4, 18, 2, 15, 3))
 
   fit <- survfit(coxph(Surv(time, status) ~ 1, data = tdata))
   fortified <- fortify(fit)
-  expected = data.frame(time = c(1, 2, 3, 4),
+  expected <- data.frame(time = c(1, 2, 3, 4),
                         n.risk = c(8, 6, 4, 2),
                         n.event = c(1, 1, 1, 1),
                         n.censor = c(1, 1, 1, 1),
@@ -97,7 +121,7 @@ test_that('fortify.survfit works for simple data', {
   expect_equal(fortified, expected)
 
   fortified <- fortify(fit, surv.connect = TRUE)
-  expected = data.frame(time = c(0, 1, 2, 3, 4),
+  expected <- data.frame(time = c(0, 1, 2, 3, 4),
                         n.risk = c(8, 8, 6, 4, 2),
                         n.event = c(1, 1, 1, 1, 1),
                         n.censor = c(0, 1, 1, 1, 1),
@@ -107,6 +131,9 @@ test_that('fortify.survfit works for simple data', {
                         lower = c(1, 0.6907374403, 0.4965890298, 0.3074348749, 0.1095982468),
                         cumhaz = c(0, 0.1250000000, 0.2916666667, 0.5416666667,1.0416666667))
   expect_equal(fortified, expected)
+
+  p <- ggplot2::autoplot(fit)
+  expect_true(is(p, 'ggplot'))
 })
 
 test_that('fortify.survfit.cox works for lung', {
@@ -117,6 +144,9 @@ test_that('fortify.survfit.cox works for lung', {
   expected_names <- c('time', 'n.risk', 'n.event', 'n.censor', 'surv',
                       'std.err', 'upper', 'lower', 'cumhaz')
   expect_equal(names(fortified), expected_names)
+
+  p <- ggplot2::autoplot(survfit(d.coxph))
+  expect_true(is(p, 'ggplot'))
 })
 
 test_that('fortify.aareg works for lung', {
@@ -134,6 +164,9 @@ test_that('fortify.aareg works for lung', {
                as.numeric(as.data.frame(expected)[nrow(expected), ]))
   expect_equal(as.numeric(fortified$time), c(0, unique(fit$time)))
 
+  p <- ggplot2::autoplot(fit)
+  expect_true(is(p, 'ggplot'))
+
   fortified <- fortify(fit, surv.connect = FALSE)
   # compare cumulated last row
   expect_equal(is.data.frame(fortified), TRUE)
